@@ -18,9 +18,12 @@ class RepositoryType(Enum):
     POSTGIS = "postgis"
     GEOTIFF = "geotiff"
     ECW = "ecw"
-    JPEG2000 = "jp2ecw"
+    JPEG2000 = "jpg2000"
     IMAGEMOSAIC = "imagemosaic"
     WORLDIMAGE = "worldimage"
+    SHAPEFILE = "shapefile"
+    SHAPEFILESDIR = "shapefiles-directory"
+    ORACLE = "oracle"
 
 
 class StyleType(Enum):
@@ -51,6 +54,8 @@ class LayerGeometry(Enum):
     MULTIPOINT = "multi-point"
     MULTILINESTRING = "multi-linestring"
     MULTIPOLYGON = "multi-polygon"
+    MULTIPOLYGON3D = "3d-multi-polygon"
+    GEOMETRYCOLLECTION = "geometry-collection"
 
 
 class LayerService(Enum):
